==> rsplib_2.7.0.orig.tar.gz: rsplib-2.7.0/rsplib/fractalpooluser_de_DE.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>FractalCalculationThread</name>
    <message>
        <source>Requesting calculation ...</source>
        <translation>Sende Berechnungsanfrage ...</translation>
    </message>
    <message>
        <source>Image completed!</source>
        <translation>Berechnung abgeschlossen!</translation>
    </message>
    <message>
        <source>Image calculation failed!</source>
        <translation>Bildberechnung fehlgeschlagen!</translation>
    </message>
    <message>
        <source>Processed packet #</source>
        <translation>Verarbeite Paket #</translation>
    </message>
    <message>
        <source>of PE</source>
        <translation>von PE</translation>
    </message>
</context>
<context>
    <name>FractalPU</name>
    <message>
        <source>Image completed</source>
        <translation>Berechnung abgeschlossen</translation>
    </message>
    <message>
        <source>Welcome to FractalPoolUser!</source>
        <translation>Willkommen zu FractalPoolUser!</translation>
    </message>
    <message>
        <source>Starting job distribution ...</source>
        <translation>Starte Verteilung der Berechnung ...</translation>
    </message>
    <message>
        <source>Image calculation failed</source>
        <translation>Bildberechnung fehlgeschlagen</translation>
    </message>
    <message>
        <source>Waiting for </source>
        <translation>Warte </translation>
    </message>
    <message>
        <source> seconds ...</source>
        <translation>s ...</translation>
    </message>
    <message>
        <source>Show &amp;Failovers</source>
        <translation>Zeige &amp;Failover</translation>
    </message>
    <message>
        <source>Show &amp;Sessions</source>
        <translation>Zeige &amp;Sitzungen</translation>
    </message>
    <message>
        <source>Sessions</source>
        <translation>Sitzungen</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Information</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>About Fractal Pool User</source>
        <translation>Über FractalPoolUser</translation>
    </message>
</context>
</TS>

==> rsplib_2.7.10.orig.tar.gz: rsplib-2.7.10/rsplib/fractalpooluser_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>FractalCalculationThread</name>
    <message>
        <source>Requesting calculation ...</source>
        <translation>Sende Berechnungsanfrage ...</translation>
    </message>
    <message>
        <source>Image completed!</source>
        <translation>Berechnung abgeschlossen!</translation>
    </message>
    <message>
        <source>Image calculation failed!</source>
        <translation>Bildberechnung fehlgeschlagen!</translation>
    </message>
    <message>
        <source>Processed packet #</source>
        <translation>Verarbeite Paket #</translation>
    </message>
    <message>
        <source>of PE</source>
        <translation>von PE</translation>
    </message>
</context>
<context>
    <name>FractalPU</name>
    <message>
        <source>Image completed</source>
        <translation>Berechnung abgeschlossen</translation>
    </message>
    <message>
        <source>Welcome to FractalPoolUser!</source>
        <translation>Willkommen zu FractalPoolUser!</translation>
    </message>
    <message>
        <source>Starting job distribution ...</source>
        <translation>Starte Verteilung der Berechnung ...</translation>
    </message>
    <message>
        <source>Image calculation failed</source>
        <translation>Bildberechnung fehlgeschlagen</translation>
    </message>
    <message>
        <source>Waiting for </source>
        <translation>Warte </translation>
    </message>
    <message>
        <source> seconds ...</source>
        <translation>s ...</translation>
    </message>
    <message>
        <source>Show &amp;Failovers</source>
        <translation>Zeige &amp;Failover</translation>
    </message>
    <message>
        <source>Show &amp;Sessions</source>
        <translation>Zeige &amp;Sitzungen</translation>
    </message>
    <message>
        <source>Sessions</source>
        <translation>Sitzungen</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Information</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>About Fractal Pool User</source>
        <translation>Über FractalPoolUser</translation>
    </message>
    <message>
        <source>&amp;Next Image</source>
        <translation type="unfinished">&amp;Nächstes Bild</translation>
    </message>
    <message>
        <source>Waiting for job completion ...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
